aboutsummaryrefslogtreecommitdiffstats
path: root/src/command/server.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/command/server.rs')
-rw-r--r--src/command/server.rs16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/command/server.rs b/src/command/server.rs
index ad7addfd..6047e5bf 100644
--- a/src/command/server.rs
+++ b/src/command/server.rs
@@ -1,20 +1,20 @@
+use clap::Parser;
use eyre::Result;
-use structopt::StructOpt;
use atuin_server::launch;
use atuin_server::settings::Settings;
-#[derive(StructOpt)]
+#[derive(Parser)]
+#[clap(infer_subcommands = true)]
pub enum Cmd {
- #[structopt(
- about="starts the server",
- aliases=&["s", "st", "sta", "star"],
- )]
+ /// Start the server
Start {
#[structopt(help = "specify the host address to bind", long, short)]
host: Option<String>,
#[structopt(help = "specify the port to bind", long, short)]
port: Option<u16>,
},
}
@@ -1,20 +1,20 @@
Start {
- #[structopt(help = "specify the host address to bind", long, short)]
+ /// The host address to bind
+ #[clap(long, short)]
host: Option<String>,
@@ -1,20 +1,20 @@
host: Option<String>,
- #[structopt(help = "specify the port to bind", long, short)]
+ /// The port to bind
+ #[clap(long, short)]
port: Option<u16>,
},